==> spip_4.1.9+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=ja
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// A
	'actualiser_toutes' => 'すべてのURLを更新する',
	'actualiser_toutes_explication' => 'URLを再処理することができます。
URLが変更された場合は、新しいエントリが作成されます（既存のURLを失うことなく、手動で定義されたURLに影響することもない）。',

	// B
	'bouton_supprimer_url' => 'このURLを削除する',

	// E
	'erreur_arbo_2_segments_max' => 'オブジェクトに対して2つ以上のURLセグメントを使用することが出来ません。',
	'erreur_config_url_forcee' => 'URLの設定は、ファイル <b>mes_options.php</b> で強制されます。',
	'explication_editer' => 'URLの高度な管理により、各編集オブジェクトのページのURLを編集し、それらの進化の履歴を管理することができます。',

	// I
	'icone_configurer_urls' => 'URLを設定する',
	'icone_controler_urls' => '意味のあるURL',
	'info_1_url' => 'URL１つ',
	'info_id_parent' => '#parent',
	'info_nb_urls' => 'URL@nb@つ',
	'info_objet' => '件名',

	// L
	'label_tri_date' => '日付',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => '新規URL',
	'label_url_minuscules_0' => 'タイトルケースを保持する',
	'label_url_minuscules_1' => 'URLを小文字に強制する',
	'label_url_permanente' => 'このURLをロックする（オブジェクトを編集した上で更新しないこと）',
	'label_url_sep_id' => '重複した場合に追加された番号を区切る文字',
	'label_urls_activer_controle_oui' => '高度なURL管理を有効にする',
	'label_urls_nb_max_car' => '最大文字数',
	'label_urls_nb_min_car' => '最小文字数',
	'liberer_url' => 'リリーズする',
	'liste_des_urls' => 'すべてのURL',

	// T
	'texte_type_urls' => '以下には、ページアドレスの処理方法を選択できます。',
	'texte_type_urls_attention' => '注意：この設定は、@htaccess@ ファイルがサイトのルートに正しくインストールされている場合にのみ機能します。',
	'texte_urls_nb_max_car' => 'タイトルが長ければ、切られます。',
	'texte_urls_nb_min_car' => 'タイトルが短い場合は、代わりにそのID番号が使用されます。',
	'titre_gestion_des_urls' => 'URLの管理',
	'titre_type_arbo' => 'ツリーのURL',
	'titre_type_html' => 'HTML オブジェクトのURL',
	'titre_type_libres' => 'フリーのURL',
	'titre_type_page' => 'ページURL',
	'titre_type_propres' => 'クリーンなURL',
	'titre_type_propres2' => 'クリーンなURL+ <tt>.html</tt>',
	'titre_type_propres_qs' => 'query-stringのクリーンなURL',
	'titre_type_simple' => '単純なURL',
	'titre_type_standard' => '元々のURL',
	'titre_type_urls' => 'URLの種類',
	'tout_voir' => 'すべてのURLを表示',

	// U
	'url_ajout_impossible' => 'エラーが発生しました。このURLを保存できませんでした。',
	'url_ajoutee' => 'URLが追加されました。',

	// V
	'verifier_url_nettoyee' => 'URLが修正されました。それを保存する前に確認することができます。',
	'verrouiller_url' => 'ロックする'
);

==> spip_4.4.11+dfsg.orig.tar.xz: plugins-dist/urls_etendues/lang/urls_ja.php <==
<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/urls?lang_cible=ja
// ** ne pas modifier le fichier **

return [

	// A
	'actualiser_toutes' => 'すべてのURLを更新する',
	'actualiser_toutes_explication' => 'URLを再処理することができます。
URLが変更された場合は、新しいエントリが作成されます（既存のURLを失うことなく、手動で定義されたURLに影響することもない）。',

	// B
	'bouton_supprimer_url' => 'このURLを削除する',

	// E
	'erreur_arbo_2_segments_max' => 'オブジェクトに対して2つ以上のURLセグメントを使用することが出来ません。',
	'erreur_config_url_forcee' => 'URLの設定は、ファイル <b>mes_options.php</b> で強制されます。',
	'explication_editer' => 'URLの高度な管理により、各編集オブジェクトのページのURLを編集し、それらの進化の履歴を管理することができます。',

	// I
	'icone_configurer_urls' => 'URLを設定する',
	'icone_controler_urls' => '意味のあるURL',
	'info_1_url' => 'URL１つ',
	'info_id_parent' => '#parent',
	'info_nb_urls' => 'URL@nb@つ',
	'info_objet' => '件名',

	// L
	'label_tri_date' => '日付',
	'label_tri_id' => 'ID',
	'label_tri_url' => 'URL',
	'label_url' => '新規URL',
	'label_url_minuscules_0' => 'タイトルケースを保持する',
	'label_url_minuscules_1' => 'URLを小文字に強制する',
	'label_url_permanente' => 'このURLをロックする（オブジェクトを編集した上で更新しないこと）',
	'label_url_sep_id' => '重複した場合に追加された番号を区切る文字',
	'label_urls_activer_controle_oui' => '高度なURL管理を有効にする',
	'label_urls_nb_max_car' => '最大文字数',
	'label_urls_nb_min_car' => '最小文字数',
	'liberer_url' => 'リリーズする',
	'liste_des_urls' => 'すべてのURL',

	// T
	'texte_type_urls' => '以下には、ページアドレスの処理方法を選択できます。',
	'texte_type_urls_attention' => '注意：この設定は、@htaccess@ ファイルがサイトのルートに正しくインストールされている場合にのみ機能します。',
	'texte_urls_nb_max_car' => 'タイトルが長ければ、切られます。',
	'texte_urls_nb_min_car' => 'タイトルが短い場合は、代わりにそのID番号が使用されます。',
	'titre_gestion_des_urls' => 'URLの管理',
	'titre_type_arbo' => 'ツリーのURL',
	'titre_type_html' => 'HTML オブジェクトのURL',
	'titre_type_libres' => 'フリーのURL',
	'titre_type_page' => 'ページURL',
	'titre_type_propres' => 'クリーンなURL',
	'titre_type_propres2' => 'クリーンなURL+ <tt>.html</tt>',
	'titre_type_propres_qs' => 'query-stringのクリーンなURL',
	'titre_type_simple' => '単純なURL',
	'titre_type_standard' => '元々のURL',
	'titre_type_urls' => 'URLの種類',
	'tout_voir' => 'すべてのURLを表示',

	// U
	'url_ajout_impossible' => 'エラーが発生しました。このURLを保存できませんでした。',
	'url_ajoutee' => 'URLが追加されました。',

	// V
	'verifier_url_nettoyee' => 'URLが修正されました。それを保存する前に確認することができます。',
	'verrouiller_url' => 'ロックする',
];
